==> haskell-prettyprinter-compat-ansi-wl-pprint-1.0.2-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-compat-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-compat-ansi-wl-pprint
version:              1.0.2
visibility:           public
id:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-4ngwMVfVgSv3sQGJJ8wwX1

key:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-4ngwMVfVgSv3sQGJJ8wwX1

license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Drop-in compatibility package to migrate from »ansi-wl-pprint« to »prettyprinter«.

description:          See README.md
category:             User Interfaces, Text
abi:                  d1ed96660f72c4d4615d882fe98fdd9b
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-compat-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-compat-ansi-wl-pprint-1.0.2-4ngwMVfVgSv3sQGJJ8wwX1

depends:
    base-4.17.2.1 prettyprinter-1.7.1-3fr7GBE89dlFqu04SpDoXe
    prettyprinter-ansi-terminal-1.1.3-IShD2EitqUFEEsKuNKe4vJ text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html/prettyprinter-compat-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-compat-ansi-wl-pprint-1.0.2-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-compat-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-compat-ansi-wl-pprint
version:              1.0.2
visibility:           public
id:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-2F3ZQlyY7DFhGLvCEtijn

key:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-2F3ZQlyY7DFhGLvCEtijn

license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Drop-in compatibility package to migrate from »ansi-wl-pprint« to »prettyprinter«.

description:          See README.md
category:             User Interfaces, Text
abi:                  25d4dfbf4c74f60e18050534253a779e
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-compat-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-compat-ansi-wl-pprint-1.0.2-2F3ZQlyY7DFhGLvCEtijn

depends:
    base-4.17.2.1 prettyprinter-1.7.1-CsTpPkPqzgLjuO06MZsX5
    prettyprinter-ansi-terminal-1.1.3-H6b8xRSUd7E1Hz5nUxGJlx text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html/prettyprinter-compat-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
